==> pytgcalls-2.0.0.dev3-py3-none-any.whl: pytgcalls/implementation/__init__.py <==
#  tgcalls - a Python binding for C++ library by Telegram
#  pytgcalls - a library connecting the Python binding with MTProto
#  Copyright (C) 2020-2021 Il`ya (Marshal) <https://github.com/MarshalX>
#
#  This file is part of tgcalls and pytgcalls.
#
#  tgcalls and pytgcalls is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  tgcalls and pytgcalls is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License v3
#  along with tgcalls. If not, see <http://www.gnu.org/licenses/>.

from pytgcalls.implementation.group_call_native import GroupCallNative
from pytgcalls.implementation.group_call_native import GroupCallNativeAction
from pytgcalls.implementation.group_call_native import GroupCallNativeDispatcherMixin

from pytgcalls.implementation.group_call_file import GroupCallFile
from pytgcalls.implementation.group_call_device import GroupCallDevice
from pytgcalls.implementation.group_call_raw import GroupCallRaw

__all__ = [
    'GroupCallNative',
    'GroupCallNativeAction',
    'GroupCallNativeDispatcherMixin',
    'GroupCallFile',
    'GroupCallDevice',
    'GroupCallRaw',
]

==> pytgcalls-3.0.0.dev10-py3-none-any.whl: pytgcalls/implementation/__init__.py <==
#  tgcalls - a Python binding for C++ library by Telegram
#  pytgcalls - a library connecting the Python binding with MTProto
#  Copyright (C) 2020-2021 Il`ya (Marshal) <https://github.com/MarshalX>
#
#  This file is part of tgcalls and pytgcalls.
#
#  tgcalls and pytgcalls is free software: you can redistribute it and/or modify
#  it under the terms of the GNU Lesser General Public License as published
#  by the Free Software Foundation, either version 3 of the License, or
#  (at your option) any later version.
#
#  tgcalls and pytgcalls is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU Lesser General Public License for more details.
#
#  You should have received a copy of the GNU Lesser General Public License v3
#  along with tgcalls. If not, see <http://www.gnu.org/licenses/>.

from pytgcalls.implementation.group_call_native import GroupCallNative

from pytgcalls.implementation.group_call import GroupCallAction
from pytgcalls.implementation.group_call import GroupCallDispatcherMixin
from pytgcalls.implementation.group_call import GroupCall

from pytgcalls.implementation.group_call_file import GroupCallFile
from pytgcalls.implementation.group_call_device import GroupCallDevice
from pytgcalls.implementation.group_call_raw import GroupCallRaw

__all__ = [
    'GroupCallNative',
    'GroupCall',
    'GroupCallAction',
    'GroupCallDispatcherMixin',
    'GroupCallFile',
    'GroupCallDevice',
    'GroupCallRaw',
]
